@@ -2,13 +2,16 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from . import account
-from . import commission
-from . import invoice
-from . import sale
-from . import product
-from . import party
-from . import ir
+
+try:
+    from trytond.modules.stock.stock_reporting_margin import \
+        Abstract as StockReportingMarginAbstract
+except ImportError:
+    StockReportingMarginAbstract = None
+
+from . import (
+    account, commission, commission_reporting, invoice, ir, party, product,
+    sale, stock, stock_reporting_margin)
 
 
 def register():
@@ -19,6 +22,9 @@ def register():
         commission.AgentSelection,
         commission.Commission,
         commission.CreateInvoiceAsk,
+        commission_reporting.Agent,
+        commission_reporting.AgentTimeseries,
+        commission_reporting.Context,
         invoice.Invoice,
         invoice.InvoiceLine,
         invoice.CreditInvoiceStart,
@@ -34,9 +40,19 @@ def register():
         sale.Line,
         module='commission', type_='model',
         depends=['sale'])
+    Pool.register(
+        stock.Move,
+        stock_reporting_margin.Context,
+        module='commission', type_='model',
+        depends=['stock'])
     Pool.register(
         commission.CreateInvoice,
         invoice.CreditInvoice,
         party.Replace,
         party.Erase,
         module='commission', type_='wizard')
+    if StockReportingMarginAbstract:
+        Pool.register_mixin(
+            stock_reporting_margin.AbstractCommissionMixin,
+            StockReportingMarginAbstract,
+            module='commission')
