@@ -1,8 +1,8 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 
-from trytond.pool import PoolMeta
 from trytond.model import ModelSQL, fields
+from trytond.pool import PoolMeta
 
 
 class Template(metaclass=PoolMeta):
@@ -25,10 +25,10 @@ class Template(metaclass=PoolMeta):
 class Template_Agent(ModelSQL):
     'Product Template - Commission Agent'
     __name__ = 'product.template-commission.agent'
-    template = fields.Many2One('product.template', 'Template',
-        required=True, select=True)
-    agent = fields.Many2One('commission.agent', 'Agent',
-        required=True, select=True,
+    template = fields.Many2One(
+        'product.template', "Template", required=True)
+    agent = fields.Many2One(
+        'commission.agent', "Agent", required=True,
         domain=[
             ('type_', '=', 'principal'),
             ])
